@@ -1,7 +1,7 @@
 package Perinci::CmdLine::Base;
 
-our $DATE = '2016-04-04'; # DATE
-our $VERSION = '1.53'; # VERSION
+our $DATE = '2016-05-09'; # DATE
+our $VERSION = '1.54'; # VERSION
 
 use 5.010001;
 use strict;
@@ -81,6 +81,13 @@ has extra_urls_for_version => (is=>'rw');
 
 has skip_format => (is=>'rw');
 
+has use_utf8 => (
+    is=>'rw',
+    default => sub {
+        $ENV{UTF8} // 0;
+    },
+);
+
 # role: requires 'hook_after_get_meta'
 # role: requires 'hook_format_row'
 # role: requires 'default_prompt_template'
@@ -497,8 +504,10 @@ sub do_completion {
     my ($words, $cword);
     if ($r->{shell} eq 'bash') {
         require Complete::Bash;
+        require Encode;
         ($words, $cword) = @{ Complete::Bash::parse_cmdline(undef, undef, {truncate_current_word=>1}) };
         ($words, $cword) = @{ Complete::Bash::join_wordbreak_words($words, $cword) };
+        $words = [map {Encode::decode('UTF-8', $_)} @$words];
     } elsif ($r->{shell} eq 'fish') {
         require Complete::Fish;
         ($words, $cword) = @{ Complete::Fish::parse_cmdline() };
@@ -588,6 +597,9 @@ sub do_completion {
         $formatted = Complete::Zsh::format_completion($compres);
     }
 
+    # to properly display unicode filenames
+    $self->use_utf8(1);
+
     [200, "OK", $formatted,
      # these extra result are for debugging
      {
@@ -1439,7 +1451,7 @@ Perinci::CmdLine::Base - Base class for Perinci::CmdLine{::Classic,::Lite}
 
 =head1 VERSION
 
-This document describes version 1.53 of Perinci::CmdLine::Base (from Perl distribution Perinci-CmdLine-Lite), released on 2016-04-04.
+This document describes version 1.54 of Perinci::CmdLine::Base (from Perl distribution Perinci-CmdLine-Lite), released on 2016-05-09.
 
 =head1 DESCRIPTION
 
@@ -2206,6 +2218,11 @@ function metadata property C<cmdline.skip_format> to true. Or, can also be done
 on a per-function result basis by returning result metadata
 C<cmdline.skip_format> set to true.
 
+=head2 use_utf8 => bool (default: from env UTF8, or 0)
+
+Whether or not to set utf8 flag on output. If undef, will default to UTF8
+environment. If that is also undef, will default to 0.
+
 =head1 METHODS
 
 =head2 $cmd->run() => ENVRES
@@ -2227,20 +2244,20 @@ Called by parse_argv() or do_completion(). Subclass has to implement this.
 
 =head1 ENVIRONMENT
 
-=over
-
-=item * PAGER => str
+=head2 PAGER => str
 
 Like in other programs, can be set to select the pager program (when
 C<cmdline.page_result> result metadata is active). Can also be set to C<''> or
 C<0> to explicitly disable paging even though C<cmd.page_result> result metadata
 is active.
 
-=item * PERINCI_CMDLINE_PROGRAM_NAME => STR
+=head2 PERINCI_CMDLINE_PROGRAM_NAME => STR
 
 Can be used to set CLI program name.
 
-=back
+=head2 UTF8 => bool
+
+To set default for C<use_utf8> attribute.
 
 =head1 HOMEPAGE
 
