@@ -1,7 +1,7 @@
 package Perinci::CmdLine::Lite;
 
-our $DATE = '2016-04-04'; # DATE
-our $VERSION = '1.53'; # VERSION
+our $DATE = '2016-05-09'; # DATE
+our $VERSION = '1.54'; # VERSION
 
 use 5.010001;
 # use strict; # already enabled by Mo
@@ -56,12 +56,6 @@ has validate_args => (
     is=>'rw',
     default => 1,
 );
-has use_utf8 => (
-    is=>'rw',
-    default => sub {
-        $ENV{UTF8} // 0;
-    },
-);
 
 my $formats = [qw/text text-simple text-pretty json json-pretty csv/];
 
@@ -476,7 +470,7 @@ Perinci::CmdLine::Lite - A lightweight Rinci/Riap-based command-line application
 
 =head1 VERSION
 
-This document describes version 1.53 of Perinci::CmdLine::Lite (from Perl distribution Perinci-CmdLine-Lite), released on 2016-04-04.
+This document describes version 1.54 of Perinci::CmdLine::Lite (from Perl distribution Perinci-CmdLine-Lite), released on 2016-05-09.
 
 =head1 SYNOPSIS
 
@@ -641,11 +635,6 @@ LOG_LEVEL/TRACE/DEBUG/VERBOSE/QUIET.
 
 =head2 validate_args => bool (default: 1)
 
-=head2 use_utf8 => bool (default: from env UTF8, or 0)
-
-Whether or not to set utf8 flag on output. If undef, will default to UTF8
-environment. If that is also undef, will default to 0.
-
 =head1 METHODS
 
 All the methods of L<Perinci::CmdLine::Base>, plus:
@@ -684,10 +673,6 @@ Set the default of C<table_column_orders> in C<format_options> in result
 metadata, similar to what's implemented in L<Perinci::Result::Format> and
 L<Data::Format::Pretty::Console>.
 
-=head2 UTF8 => bool
-
-To set default for C<use_utf8> attribute.
-
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/Perinci-CmdLine-Lite>.
